==> everrest-groovy-1.1.2-sources.jar: org/everrest/groovy/servlet/GroovyEverrestInitializedListener.java <==
/**
 * Copyright (C) 2010 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.everrest.groovy.servlet;

import org.everrest.core.impl.EverrestProcessor;
import org.everrest.core.servlet.EverrestServletContextInitializer;

import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import javax.ws.rs.core.Application;

/**
 * @author <a href="mailto:andrew00x@gmail.com">Andrey Parfonov</a>
 * @version $Id$
 */
public class GroovyEverrestInitializedListener implements ServletContextListener {

    /** {@inheritDoc} */
    public void contextDestroyed(ServletContextEvent event) {
    }

    /** {@inheritDoc} */
    public void contextInitialized(ServletContextEvent event) {
        ServletContext sctx = event.getServletContext();
        EverrestProcessor processor = (EverrestProcessor)sctx.getAttribute(EverrestProcessor.class.getName());
        if (processor == null)
            throw new RuntimeException("EverrestProcessor not found. ");
        EverrestServletContextInitializer initializer = new GroovyEverrestServletContextInitializer(sctx);
        Application application = initializer.getApplication();
        if (application != null)
            processor.addApplication(application);
    }
}

==> everrest-groovy-1.9.0-sources.jar: org/everrest/groovy/servlet/GroovyEverrestInitializedListener.java <==
/*******************************************************************************
 * Copyright (c) 2012-2014 Codenvy, S.A.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Codenvy, S.A. - initial API and implementation
 *******************************************************************************/
package org.everrest.groovy.servlet;

import org.everrest.core.impl.EverrestProcessor;
import org.everrest.core.servlet.EverrestServletContextInitializer;

import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import javax.ws.rs.core.Application;

/**
 * @author andrew00x
 */
public class GroovyEverrestInitializedListener implements ServletContextListener {


    @Override
    public void contextDestroyed(ServletContextEvent event) {
    }


    @Override
    public void contextInitialized(ServletContextEvent event) {
        ServletContext sctx = event.getServletContext();
        EverrestProcessor processor = (EverrestProcessor)sctx.getAttribute(EverrestProcessor.class.getName());
        if (processor == null) {
            throw new RuntimeException("EverrestProcessor not found. ");
        }
        EverrestServletContextInitializer initializer = new GroovyEverrestServletContextInitializer(sctx);
        Application application = initializer.getApplication();
        if (application != null) {
            processor.addApplication(application);
        }
    }
}
